pub fn fallback() -> Option<Fallback>Available on crate feature
base only.Expand description
Returns the Fallback function of this contract, if any.
pub fn fallback() -> Option<Fallback>base only.Returns the Fallback function of this contract, if any.